==> e93-1.3r4X.tgz: e93/xgui/window.h <==
// This file is part of e93.
//
// e93 is free software; you can redistribute it and/or modify
// it under the terms of the e93 LICENSE AGREEMENT.
//
// e93 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// e93 LICENSE AGREEMENT for more details.
//
// You should have received a copy of the e93 LICENSE AGREEMENT
// along with e93; see the file "LICENSE.TXT".


// this is the WINDOW_LIST_ELEMENT structure which allows us to get
// back from an X window to the editor window structures

typedef struct windowListElement				// this structure is used to locate our data based on an x window ID
{
	Window
		xWindow;								// x window id
	Window
		realTopWindow;							// since window managers can reparent my windows (bad concept), and since it is necessary keep track of the hierarchy of editor windows, when a window is created, the true root level parent is determined and stored here
	GC
		graphicsContext;						// graphics context for the given window
	Region
		invalidRegion;							// the region that collects our invalidation information
	EDITOR_WINDOW
		*theEditorWindow;						// pointer to our editor window structure
	Pixmap
		currentIcon;							// tells which icon is currently in use for the window (NULL if none)
	struct windowListElement
		*nextElement,							// next one of our windows, or NULL if none
		*previousElement;						// previous window, or NULL if none
} WINDOW_LIST_ELEMENT;


void GetEditorScreenDimensions(UINT32 *theWidth,UINT32 *theHeight);
void InvalidateWindowRect(EDITOR_WINDOW *theWindow,EDITOR_RECT *theRect);
void InvalidateWindowRegion(EDITOR_WINDOW *theWindow,Region theRegion);
void RedrawInvalidWindows();
void SetRealTopWindow(WINDOW_LIST_ELEMENT *theElement);
void WaitUntilMappedNoFocus(EDITOR_WINDOW *theWindow);
void WaitUntilMapped(EDITOR_WINDOW *theWindow);
void WaitUntilDestroyed(EDITOR_WINDOW *theWindow);
void LinkWindowElement(WINDOW_LIST_ELEMENT *theElement);
void UnlinkWindowElement(WINDOW_LIST_ELEMENT *theElement);
WINDOW_LIST_ELEMENT *LocateWindowElement(Window xWindow);
void MinimizeEditorWindow(EDITOR_WINDOW *theWindow);
void UnminimizeEditorWindow(EDITOR_WINDOW *theWindow);
EDITOR_WINDOW *GetTopEditorWindow();
void SetTopEditorWindow(EDITOR_WINDOW *theWindow);
EDITOR_WINDOW *GetTopEditorWindowType(UINT16 windowType);
bool GetSortedEditorWindowTypeList(UINT16 windowType,UINT32 *numElements,EDITOR_WINDOW ***theList);
EDITOR_WINDOW *GetEditorFocusWindow();
void FocusAwayFrom(EDITOR_WINDOW *theWindow);

==> e93-1.4r2X.tgz: e93/xgui/window.h <==
// This file is part of e93.
//
// e93 is free software; you can redistribute it and/or modify
// it under the terms of the e93 LICENSE AGREEMENT.
//
// e93 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// e93 LICENSE AGREEMENT for more details.
//
// You should have received a copy of the e93 LICENSE AGREEMENT
// along with e93; see the file "LICENSE.TXT".


// this is the WINDOW_LIST_ELEMENT structure which allows us to get
// back from an X window to the editor window structures

typedef struct windowListElement				// this structure is used to locate our data based on an x window ID
{
	Window
		xWindow;								// x window id
	Window
		realTopWindow;							// since window managers can reparent my windows (bad concept), and since it is necessary keep track of the hierarchy of editor windows, when a window is created, the true root level parent is determined and stored here
	Region
		invalidRegion;							// the region that collects our invalidation information
	EDITOR_WINDOW
		*editorWindow;							// pointer to our editor window structure
	Pixmap
		currentIcon;							// tells which icon is currently in use for the window (NULL if none)
	struct windowListElement
		*nextElement,							// next one of our windows, or NULL if none
		*previousElement;						// previous window, or NULL if none
} WINDOW_LIST_ELEMENT;


void GetEditorDisplayDimensions(UINT32 *width,UINT32 *height);
void GetEditorScreenOffsetAndDimensions(INT32 *xOffset,INT32 *yOffset,UINT32 *width,UINT32 *height);
void InvalidateWindowRect(EDITOR_WINDOW *window,EDITOR_RECT *rect);
void InvalidateWindowRegion(EDITOR_WINDOW *window,Region region);
void RedrawInvalidWindows();
void SetClassHints(EDITOR_WINDOW *window);
void SetRealTopWindow(WINDOW_LIST_ELEMENT *element);
void WaitUntilMappedNoFocus(EDITOR_WINDOW *window);
void WaitUntilMapped(EDITOR_WINDOW *window);
void WaitUntilDestroyed(EDITOR_WINDOW *window);
void LinkWindowElement(WINDOW_LIST_ELEMENT *element);
void UnlinkWindowElement(WINDOW_LIST_ELEMENT *element);
WINDOW_LIST_ELEMENT *LocateWindowElement(Window xWindow);
void MinimizeEditorWindow(EDITOR_WINDOW *window);
void UnminimizeEditorWindow(EDITOR_WINDOW *window);
EDITOR_WINDOW *GetTopEditorWindow();
void SetTopEditorWindow(EDITOR_WINDOW *window);
EDITOR_WINDOW *GetTopEditorWindowType(UINT16 windowType);
bool GetSortedEditorWindowTypeList(UINT16 windowType,UINT32 *numElements,EDITOR_WINDOW ***list);
EDITOR_WINDOW *GetEditorFocusWindow();
void FocusAwayFrom(EDITOR_WINDOW *window);
